KIWI - Boxed Build Plugin
=========================

.. |Build Status| image:: https://travis-ci.com/OSInside/kiwi-boxed-plugin.svg?branch=master
   :target: https://travis-ci.com/OSInside/kiwi-boxed-plugin

|Build Status|

KIWI plugin to provide self contained build support
